@@ -31,11 +31,18 @@ def add_renderer_globals(event):
     # regular request, the request will be None, so globals can't be set
     if request is None:
         return
-    layout_manager = request.layout_manager
-    layout = layout_manager.layout
-    event['layout'] = layout
-    event['main_template'] = layout.__template__
-    event['panel'] = layout_manager.render_panel
+
+    # It is possible for add render globals to get called without a context
+    # being found.  This generally happens when there is an error finding
+    # the context and then an error handler which uses a renderer is
+    # called, such as would be the case if pyramid_debugtoolbar were
+    # being used.
+    layout_manager = getattr(request, 'layout_manager', None)
+    if layout_manager:
+        layout = layout_manager.layout
+        event['layout'] = layout
+        event['main_template'] = layout.__template__
+        event['panel'] = layout_manager.render_panel
 
 
 def create_layout_manager(event):
@@ -268,11 +275,11 @@ class _PanelMapper(object):
 
     def map_class(self, panel):
         attr = self.attr
-        def class_panel(context, request):
+        def class_panel(context, request, *args, **kw):
             inst = panel(context, request)
             if attr is None:
-                return inst()
-            return getattr(inst, attr)()
+                return inst(*args ,**kw)
+            return getattr(inst, attr)(*args, **kw)
         return class_panel
 
 
